@@ -28,7 +28,7 @@ known_working_groups = [
     "RTA",
     "Simulation",
     "SL",
-    "Tagging",
+    "FlavourTagging",
     "Tracking",
 ]
 
