@@ -1,5 +1,5 @@
 ###############################################################################
-# (c) Copyright 2020 CERN for the benefit of the LHCb Collaboration           #
+# (c) Copyright 2020-2022 CERN for the benefit of the LHCb Collaboration      #
 #                                                                             #
 # This software is distributed under the terms of the GNU General Public      #
 # Licence version 3 (GPL Version 3), copied verbatim in the file "COPYING".   #
@@ -15,9 +15,16 @@ from os.path import dirname, join
 
 
 def project_uses_cmt(app_name, app_version):
-    """Determine if a application needs the CMT fallback to be applied
+    """Determine if a application needs the CMT fallback to be applied.
 
     This does not aim to be comprehensive.
+
+    Args:
+        app_name (str): LHCb application name.
+        app_version (str): LHCb application version.
+
+    Returns:
+        bool: whether the application/version should have the fallback applied.
     """
     if app_name.lower() != "davinci":
         return False
@@ -30,7 +37,13 @@ def project_uses_cmt(app_name, app_version):
 
 
 def setup_lbrun_environment(siteroot, repository_dir, setup_cmt):
-    """Set up the fake siteroot for lb-run to use when testing"""
+    """Set up the fake siteroot for lb-run to use when testing.
+
+    Args:
+        siteroot (str): The directory where the lb-run fake siteroot will be created
+        repository_dir (str): Repository directory
+        setup_cmt (bool): whether to use fallback hack for CMT-style projects
+    """
     os.environ["CMAKE_PREFIX_PATH"] = str(siteroot)
     fake_dbase = join(siteroot, "DBASE")
     fake_install_dir = join(fake_dbase, "AnalysisProductions", "v999999999999")
